c      historysf.inc
c            rashafer 29 April 1986
c               M A Sweeney 24 July 1986
c            rashafer 21 Octoper 1986
c      XSPEC include file with the definitions of the history package
c      header and subsidiary info records

c HIS_DATA_FILES
c    charbuf     c*85     buffer (union with rest of structure)
c    dgrpno      i        The data group number
c    nchan       i        The total number of detector channels
c    nbin        i        The current number of bins in the file
c    newfile     l*1      The file has changed since the last package
c    fname       c*72     The data file name

      INTEGER len_his_data_files
      PARAMETER (len_his_data_files=85)
      STRUCTURE/his_data_files/
         UNION
            MAP
               CHARACTER*85 charbuf
            END MAP
            MAP
               INTEGER dgrpno      
               INTEGER nchan      
               INTEGER nbin      
               LOGICAL*1 newfile      
               CHARACTER*72 fname      
           END MAP
         END UNION
      END STRUCTURE

c HIS_ASSOC_FILES
c    charbuf     c*77     buffer (union with rest of structure)
c    index       i        The index of the corresponding data file
c    type        c*1      The type of file, 'R' indicates
c                         a response, 'B' a background, and 'C'
c                         a correction file.
c    fname       c*72     The file name

      INTEGER len_his_assoc_files
      PARAMETER (len_his_assoc_files=77)
      STRUCTURE/his_assoc_files/
         UNION
            MAP
               ChARACTER*77 charbuf
            END MAP
            MAP
               INTEGER index      
               CHARACTER*1 type      
               CHARACTER*72 fname      
            END MAP
         END UNION
      END STRUCTURE

c HIS_CHANNELS
c    nset        i        The number of consecutive bins with same
c                         number of binned channels
c    nsize       i        The number of channels per bin in thge set
c    nstart      i        The start channel of the first bin in the set
c    nchan       i        The start file bin number of the first bin
c                         in the set

      INTEGER len_his_channels
      PARAMETER(len_his_channels=16)
      STRUCTURE/his_channels/
         INTEGER nset      
         INTEGER nsize      
         INTEGER nstart     
         INTEGER nchan      
      END STRUCTURE

c HIS_MODEL
c    dgrpno     i         The data group number (currently :=1)
c    groupno    i         The model group number (0 for the initial
c                         all-multiplicative group of models applied
c                         to the entire set of models)
c    compno     i         The component number within a particular
c                         group (multiplicative models by definition
c                         have compno's larger than all additive models
c                         of a group).
c    spare(8)   b         spare.
c    mname      c*8       The model name (as many as 8 characters).

      INTEGER len_his_model
      PARAMETER(len_his_model=28)
      STRUCTURE/his_model/
         INTEGER dgrpno    
         INTEGER groupno   
         INTEGER compno    
         BYTE spare(8)       
         CHARACTER*8 mname   
      END STRUCTURE

c HIS_PARAM_DEF
c    modind     i         The index of the model, i.e. it was described
c                         by the modind'th subsidiary record of the model
c                         package.
c    parno      i         The corresponding PARAMETER no. of that model
c                         (n.b. that the normalization of a model has a
c                         parno = 0).
c    fitind     i         The corresponding fit PARAMETER index.
c    spare(8)   b         spare
c    pname      c*8       The name of the PARAMETER (as many as 8 
c                         characters.

      INTEGER len_his_param_def
      PARAMETER(len_his_param_def=28)
      STRUCTURE/his_param_def/
         INTEGER modind    
         INTEGER parno     
         INTEGER fitind    
         BYTE spare(8)       
         CHARACTER*8 pname   
      END STRUCTURE

c HIS_PARAM_RANGE
c    fitind     i         The fit PARAMETER index.
c    init       r         The initial value.
c    delta      r         The step size (also indicates frozen/thawed 
c                         status.
c    hardlw     r         The hard lower limit.
c    softlw     r         The soft lower limit.
c    softhi     r         The soft upper limit.
c    hardhi     r         The hard upper limit.


      INTEGER len_his_param_range
      PARAMETER(len_his_param_range=28)
      STRUCTURE/his_param_range/
         INTEGER fitind    
         REAL init         
         REAL delta        
         REAL hardlw       
         REAL softlw       
         REAL softhi       
         REAL hardhi       
      END STRUCTURE

      INTEGER max_no_fit
      PARAMETER(max_no_fit=50)

c HIS_FIT
c     error     i         The value of the error flag at the end of the 
c                         fit process.
c     chisqr    r         The value of chi-squared.
c     funct(3)  r         Function values
c     nfit      i         The number of fit PARAMETERs

      INTEGER len_his_fit
      PARAMETER(len_his_fit=24)
      STRUCTURE/his_fit/
         INTEGER error      
         REAL chisqr      
         REAL funct(3)      
         INTEGER nfit      
      END STRUCTURE

c HIS_FIT_SUB1
c     value     r         The values of every fit PARAMETER

      INTEGER len_his_fit_sub1
      PARAMETER(len_his_fit_sub1=4*max_no_fit)
      STRUCTURE/his_fit_sub1/
         REAL value(max_no_fit)      
      END STRUCTURE

c HIS_FIT_SUB2
c     esterr    r         The estimated errors of every fit
c                         PARAMETER (from the correlation matrix).

      INTEGER len_his_fit_sub2
      PARAMETER(len_his_fit_sub2=4*max_no_fit)
      STRUCTURE/his_fit_sub2/
         REAL esterr(max_no_fit)      
      END STRUCTURE

c HIS_STEPPAR_SUB1
c     fitind    i         The fit index number.
c     nstep     i         The number of steps.
c     lowpar    r         The lower limit of the stepping.
c     hipar     r         The upper limit of the stepping.
c     log       l         If true the steps are logarithmic.

      INTEGER len_his_steppar_sub1
      PARAMETER(len_his_steppar_sub1=20)
      STRUCTURE/his_steppar_sub1/
         INTEGER fitind    
         INTEGER nstep     
         REAL lowpar       
         REAL hipar        
         LOGICAL*4 log       
      END STRUCTURE

c HIS_STEPPAR
c    nspar      i         The number of PARAMETERs being stepped.
c    chimin     r         The minimum value of chisquare (on entry)

      INTEGER len_his_steppar
      PARAMETER(len_his_steppar=8)
      STRUCTURE/his_steppar/
         INTEGER nspar      
         REAL chimin       
      END STRUCTURE

c HIS_STEPPAR_SUB2
c    errflag    i         The error flag returned by the fit
c    chisqr     r         The statistic value
c    funct(3)   r         Function values
c    par        r         The value of the stepped PARAMETERs

      INTEGER len_his_steppar_sub2,len_his_steppar_sub2_ini
      INTEGER max_singsteppar
      PARAMETER(max_singsteppar=4)
      PARAMETER(len_his_steppar_sub2_ini=20)
      PARAMETER(len_his_steppar_sub2
     &            =len_his_steppar_sub2_ini+4*max_singsteppar)
      STRUCTURE/his_steppar_sub2/
         INTEGER errflag      
         REAL chisqr      
         REAL funct(3)      
         REAL par(max_singsteppar) 
      END STRUCTURE

c HIS_ERROR
c    errflag    i         Indications of an error in the determination.
c    chisqr     r         Minimum chi-squared.
c    delchi     r         The delta chi-squared defining the confidence
c                         range.
c    fitind     i         The fit PARAMETER no.
c    best       r         The best fit value.
c    low        r         The lower fit value.
c    high       r         The higher fit value.
c    dellow     r         The actual lower limit delta chi-squared.
c    delhi      r         The actual upper limit delta chi-squared.
c    peglow     l*1       If true, the lower value is pegged.
c    peghi      l*1       If true, the upper value is pegged.
c    funct(3)   r         The best fit function value
c    functlw(3) r         The lower fit function value
c    functhi(3) r         The upper fit function value

      INTEGER len_his_error
      PARAMETER(len_his_error=74)
      STRUCTURE/his_error/
         INTEGER errflag   
         REAL chisqr       
         REAL delchi       
         INTEGER fitind    
         REAL best         
         REAL low          
         REAL high         
         REAL dellow       
         REAL delhi        
         REAL funct(3)     
         REAL functlw(3)   
         REAL functhi(3)   
         logical*1 peglow    
         logical*1 peghi     
      END STRUCTURE

c HIS_EQUIV_WIDTH
c    modind     i         The model index whose equivalent width is being
c                         estimated.
c    ecnt       r         The energy at which the continuum is evaluated.
c    cntpht     r         The continuum photon flux at ECNT.
c    econlw     r         The lower limit of the continuum integration.
c    econhi     r         The upper limit of the continuum integration.
c    modpht     r         The model component photon flux.
c    emodlw     r         The lower limit of the model integration.
c    emodhi     r         The upper limit of the model integration.
c    eqp        r         The equivalent width (using photon numbers).
c    spare(14)  b         spare.

      INTEGER len_his_equiv_width
      PARAMETER(len_his_equiv_width=50)
      STRUCTURE/his_equiv_width/
         INTEGER modind    
         REAL ecnt         
         REAL cntpht       
         REAL econlw       
         REAL econhi       
         REAL modpht       
         REAL emodlw       
         REAL emodhi       
         REAL eqp          
         BYTE spare(14)       
      END STRUCTURE

c HIS_FLUX
c    elow       r         The lower limit of the integration.
c    ehi        r         The upper limit of the integration.
c    pflux      r         The integrated number of model photons.
c    eflux      r         The integrated energy flux.

      INTEGER len_his_flux
      PARAMETER(len_his_flux=16)
      STRUCTURE/his_flux/
         REAL elow         
         REAL ehi          
         REAL pflux        
         REAL eflux        
      END STRUCTURE

c HIS_FLUM
c    elow       r         rest frame lower energy for luminosity calc
c    ehi        r         upper energy
c    redz       r         redshift
c    q0         r         deceleration PARAMETER
c    h0         r         Hubble constant in units 100 km/s/Mpc
c    flxrp      r         photon flux
c    flume      r         luminosity

      INTEGER len_his_flum
      PARAMETER(len_his_flum=32)
      STRUCTURE/his_flum/
         REAL elow
         REAL ehi
         REAL redz
         REAL q0
         REAL h0
         REAL flxrp
         REAL flume
      END STRUCTURE

c HIS_TIME
c    ctime      c*20      A character representation of the date and 
c                         time.
c    deltim     r         Elapsed clock time (seconds).
c    perform(5) i         An array of values used to measure performance
c                           (1) elapsed real time in 10msec tics
c                           (2) elapsed CPU time in 10msec tics
c                           (3) buffered I/O count
c                           (4) direct I/O count
c                           (5) page fault count

      INTEGER len_his_time
      PARAMETER(len_his_time=44)
      STRUCTURE/his_time/
         CHARACTER*20 ctime  
         REAL deltim       
         INTEGER perform(5)
      END STRUCTURE

c HIS_SPECTRUM
c    nbin       i         The total number of bins after ignore
c                         and notice commands
c    eunits     c*24      The energy units
c    sunits     c*24      The spectrum units

      INTEGER len_his_spectrum
      PARAMETER(len_his_spectrum=52)
      STRUCTURE/his_spectrum/
         INTEGER nbin      
         CHARACTER*24 eunits      
         CHARACTER*24 sunits      
      END STRUCTURE

c HIS_SPECTRUM_SUB
c    elow       r         The lower energy boundary
c    ehi        r         The upper energy boundary
c    phaobs     r         The observed spectrum
c    phaerr     r         The errors
c    phamod     r         The model spectrum

      INTEGER len_his_spectrum_sub
      PARAMETER(len_his_spectrum_sub=20)
      STRUCTURE/his_spectrum_sub/
         REAL elow            
         REAL ehi            
         REAL phaobs      
         REAL phaerr      
         REAL phamod      
      END STRUCTURE

c HIS_PHOTON
c    nerg       i         The total number of energy ranges 
c                         after ignore and notice commands
c    eunits     c*24      The energy units
c    munits     c*40      The model units

      INTEGER len_his_photon
      PARAMETER(len_his_photon=68)
      STRUCTURE/his_photon/
         INTEGER nerg
         CHARACTER*24 eunits
         CHARACTER*40 munits               
      END STRUCTURE

c HIS_PHOTON_SUB
c    elow       r         The lower energy boundary
c    ehi        r         The upper energy boundary
c    photflux   r         The model spectrum (not folded)

      INTEGER len_his_photon_sub
      PARAMETER(len_his_photon_sub=12)
      STRUCTURE/his_photon_sub/
         REAL elow            
         REAL ehi            
         REAL photflux      
      END STRUCTURE

c HIS_UFSPEC
c    nbin       i         The total number of bins after ignore
c                         and notice commands
c    eunits     c*24      The energy units
c    sunits     c*24      The spectrum units

      INTEGER len_his_ufspec
      PARAMETER(len_his_ufspec=52)
      STRUCTURE/his_ufspec/
         INTEGER nbin      
         CHARACTER*24 eunits      
         CHARACTER*24 sunits      
      END STRUCTURE

c HIS_UFSPEC_SUB
c    elow       r         The lower energy boundary
c    ehi        r         The upper energy boundary
c    phaobs     r         The unfolded spectrum
c    phaerr     r         The errors

      INTEGER len_his_ufspec_sub
      PARAMETER(len_his_ufspec_sub=16)
      STRUCTURE/his_ufspec_sub/
         REAL elow            
         REAL ehi            
         REAL phaobs      
         REAL phaerr      
      END STRUCTURE


